#author: Amol Umrale

import re

from .tlds import tlds


class UrlException(Exception):
	pass


class UrlParseException(Exception):
	pass


class AbsUrl():
	regex = re.compile(	"^([a-zA-Z][a-zA-Z0-9+-\.]+)://" +		#scheme
				"(?:(?:" +
					"(?:(" +
						"(?:[a-zA-Z0-9]{1,64}\.)*" +			#subdomain
						"(?:[a-zA-Z][a-zA-Z0-9-]{0,63})" +		#hostname
						"(?:\.[a-zA-Z]{2,3}(?:\.[a-zA-Z]{2,3})?)" +	#tld
					")|(" +
						"(?:[a-zA-Z][a-zA-Z0-9-]{0,63})" +		#local hostname
					"))" +
				")|(" +
					"[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}" +	#ip address
				"))" +
				"[/\?]?.*$")					#rest of the url

	def __init__(self, url):
		self._url = url
		self._tld = None
		self._hostname = None
		self._subdomain = None
		self._scheme = None
		self._valid = None
		self.parse()


	def parse(self):
		match = self.regex.match(self._url)
		
		if match is None:
			self._valid = False
			return

		self._valid = True
		self._scheme = match.group(1)

		if match.group(2) is not None:
			parts = match.group(2).split('.')
			
			if len(parts[-2]) <= 3 and parts[-2] in tlds:		#length check is a dirty fix for tlds which are also
				self._tld = parts[-2] + '.' + parts[-1]		#valid domain names
				del parts[-1]
				del parts[-1]

			else:
				self._tld = parts[-1]
				del parts[-1]

			if len(parts) == 0:
				raise UrlParseException('%s does not have a valid domain name'%self._url)

			self._hostname = parts[-1]
			del parts[-1]

			if len(parts) > 0:
				self._subdomain = '.'.join(parts)
		
		elif match.group(3) is not None:		#local hostname
			self._hostname = match.group(3)

		elif match.group(4) is not None:		#ip address
			self._hostname = match.group(4)


	def get_hostname(self):
		return self._hostname


	def get_tld(self):
		return self._tld


	def get_domain(self):
		return self._hostname + (('.' + self._tld) if self._tld is not None else '')


	def get_subdomain(self):
		return self._subdomain


	def get_scheme(self):
		return self._scheme


	def is_valid(self):
		return self._valid


	def extend(self, url):
		if not self._valid:
			raise UrlException('base url invalid')

		rel_url = RelUrl(url)

		if rel_url.protocol_relative:
			extended_url = self._scheme + '://' + rel_url.url
			return extended_url

		search_start_pos = len(self._scheme) + 3
		end_pos = None

		if rel_url.root_relative:
			end_pos = self._url.find('/', search_start_pos)
		else:
			end_pos = self._url.rfind('/', search_start_pos)
		if end_pos < 0:
			end_pos = self._url.find('?', search_start_pos)
		if end_pos < 0:
			end_pos = len(self._url)

		if rel_url.root_relative:		
			extended_url = self._url[0:end_pos] + '/' + rel_url.url
			return extended_url
		
		base_url = self._url[0:end_pos]
		base_parts = base_url.split('/')

		if rel_url.up > (len(base_parts) - 3):
			raise UrlException('invalid number of levels up')

		base_parts = base_parts[0:len(base_parts)-rel_url.up]
		extended_url = '/'.join(base_parts) + '/' + rel_url.url
		
		return extended_url


	hostname = property(get_hostname)
	tld = property(get_tld)
	domain = property(get_domain)
	subdomain = property(get_subdomain)
	scheme = property(get_scheme)
	valid = property(is_valid)


class RelUrl():
	def __init__(self, url):
		self._url = url
		self._up = 0
		self._root_rel = False
		self._proto_rel = False
		self.parse()


	def parse(self):
		if self._url.startswith('//'):
			self._proto_rel = True
			self._url = self._url[2:]
			return

		if self._url.startswith('/'):		#url relative to root
			self._root_rel = True
			self._url = self._url[1:]
			return
		
		while self._url.startswith('../'):
			self._up += 1
			self._url = self._url[3:]

		while self._url.startswith('./'):
			self._url = self._url[2:]

		if self._url.startswith('/'):		#clean any extraneous front slashes
			self._url = self._url[1:]


	def get_url(self):
		return self._url


	def get_up(self):
		return self._up

	
	def get_root_rel(self):
		return self._root_rel


	def get_proto_rel(self):
		return self._proto_rel


	url = property(get_url)
	up = property(get_up)
	root_relative = property(get_root_rel)
	protocol_relative = property(get_proto_rel)




cdns = [
	'akamai.net',
	'akamaiedge.net',
	'akamaihd.net',
	'edgesuite.net',
	'edgekey.net',
	'srip.ne',
	'akamaitechnologies.com',
	'akamaitechnologies.fr',
	'llnwd.net',
	'edgecastcdn.net',
	'systemcdn.net',
	'transactcdn.net',
	'v1cdn.net',
	'v2cdn.net',
	'v3cdn.net',
	'v4cdn.net',
	'v5cdn.net',
	'hwcdn.net',
	'simplecdn.net',
	'instacontent.net',
	'footprint.net',
	'ay1.b.yahoo.com',
	'yimg.',
	'yahooapis.com',
	'google.',
	'googlesyndication.',
	'youtube.',
	'googleusercontent.com',
	'googlehosted.com',
	'gstatic.com',
	'insnw.net',
	'inscname.net',
	'internapcdn.net',
	'cloudfront.net',
	'netdna-cdn.com',
	'netdna-ssl.com',
	'netdna.com',
	'cotcdn.net',
	'cachefly.net',
	'bo.lt',
	'cloudflare.com',
	'afxcdn.net',
	'lxdns.com',
	'att-dsa.net',
	'vo.msecnd.net',
	'voxcdn.net',
	'bluehatnetwork.com',
	'swiftcdn1.com',
	'cdngc.net',
	'gccdn.net',
	'panthercdn.com',
	'fastly.net',
	'nocookie.net',
	'gslb.taobao.com',
	'gslb.tbcache.com',
	'mirror-image.net',
	'yottaa.net',
	'cubecdn.net',
	'r.cdn77.net',
	'incapdns.net',
	'bitgravity.com',
	'r.worldcdn.net',
	'r.worldssl.net',
	'tbcdn.cn',
	'taobaocdn.com',
	'ngenix.net',
	'pagerain.net',
	'ccgslb.com',
	'cdn.sfr.net',
	'azioncdn.net',
	'azioncdn.com',
	'azion.net',
	'cdncloud.net.au',
	'rncdn1.com',
	'cdnsun.net',
	'mncdn.com',
	'mncdn.net',
	'mncdn.org',
	'cdn.jsdelivr.net',
	'nyiftw.net',
	'nyiftw.com',
	'resrc.it',
	'zenedge.net',
	'lswcdn.net',
	'revcn.net',
	'revdn.net',
	'caspowa.com'
]



from urllib2 import urlopen

tlds_list_url = 'http://data.iana.org/TLD/tlds-alpha-by-domain.txt'

def update():
	text = None

	try:
		response = urlopen(tlds_list_url)
		text = response.read()
		response.close()
	except HTTPError as e:
		print e.message
		return

	tlds = []
	for line in text.splitlines():
		line = line.strip()
		if line.startswith('#'):
			continue
		tlds.append(line.lower())
		
	with open('tlds.py', 'w') as f:
		f.write('tlds = [\n')
		for tld in tlds[0:-1]:
			f.write('\t\'%s\',\n'%tld)
		f.write('\t\'%s\'\n'%tlds[-1])
		f.write(']\n')

	print('%d tlds; tlds.py written.'%len(tlds))


if __name__ == '__main__':
	update()




from urllib2 import urlopen
import re


src_url = 'https://raw.githubusercontent.com/WPO-Foundation/webpagetest/master/agent/wpthook/cdn.h'

def update():
	response = urlopen(src_url)
	text = response.read()
	response.close()

	cdn_list_regex = re.compile("CDN_PROVIDER\s+cdnList.*?END_MARKER", re.M | re.S)
	matches = cdn_list_regex.findall(text)

	if matches is None:
		print('error in finding cdn list in source')
		return

	cdn_list_text = matches[0]
	
	lines = cdn_list_text.splitlines()
	del lines[0]
	del lines[-1]

	cdn_record_regex = re.compile("\"(.*?)\"")
	cdn_list = []

	for line in lines:
		matches = cdn_record_regex.findall(line)
		if matches is not None:
			cdn_name = matches[0]
			cdn_list.append(cdn_name.lstrip('.'))

	with open('cdns.py', 'w') as f:
		f.write('cdns = [\n')
		f.write(',\n'.join(['\t\'%s\''%cdn for cdn in cdn_list]))
		f.write('\n]\n')

	print('cdns.py updated')


if __name__ == '__main__':
	update()




from mangoutils.system import *
if is_py3():
	from html.parser import HTMLParser
else:	
	from HTMLParser import HTMLParser
from xml.etree.ElementTree import XMLParser, Element, SubElement, ElementTree
import re
import sys


class DebugDump():
	def __init__(self, debug=False, filter=None, children=True):
		self._debug = debug
		self._filter = filter
		self._start_level = None

	
	def dump_tag(self, tag, attrs=None, end=False, level=0, msg=None):
		if self._debug:
			if self._filter and self._start_level is None:
				matches = [(k, v) for (k, v) in self._filter if (k, v) in attrs] if attrs else []
				#print matches
				if len(matches) == 0:
					return
				self._start_level = level

			if self._start_level is not None:
				if end:
					if level == self._start_level:
						self._start_level = None
			
			spaces = ''.join([' ' for i in range(level)])
			attr_string = None
			if attrs:
				attr_string = ''
				for (k, v) in attrs:
					attr_string += ' ' + str(k) + '=\"' + str(v) + '\"'
			print(('%s<%s%s%s>%s'%(spaces, ('/' if end else ''), tag, (attr_string if attr_string else ''),
						(' ' + msg if msg else ''))))
		

class HtmlParser(HTMLParser):
	def __init__(self, skip_tags=[], ddump=None):
		self._root = None
		self._stack = []
		self._skip_tags = skip_tags
		self._skip = False, None
		self._ddump = ddump

		if is_py3():
			HTMLParser.__init__(self, convert_charrefs=True)
		else:
			HTMLParser.__init__(self)

	
	def handle_starttag(self, tag, attrs):
		if self._skip[0] == True:
			return
		if tag in self._skip_tags:
			self._skip = True, tag
			return

		if self._ddump: self._ddump.dump_tag(tag, attrs, level=len(self._stack))

		attr_dict = dict((k, v) for (k, v) in attrs)
		if self._root == None:
			self._root = Element(tag, attr_dict)
			self._stack.append(self._root)
		else:
			e = SubElement(self._stack[-1], tag, attr_dict)
			self._stack.append(e)


	def handle_endtag(self, tag):
		if self._skip[0] == True:
			if tag == self._skip[1]:
				self._skip = False, None
			return
		
		if tag == self._stack[-1].tag or True:
			self._stack.pop()
		else:
			if self._ddump:
				m = self._stack[-1]
				attrs = [(k, v) for (k, v) in list(m.attrib.items())]
				self._ddump.dump_tag(m.tag, attrs=attrs, level=len(self._stack), msg='mismatch')

		if self._ddump: self._ddump.dump_tag(tag, end=True, level=len(self._stack))


	def handle_data(self, data):
		if self._skip[0]:
			return

		if self._stack:
			if self._stack[-1].text:
				self._stack[-1].text += data
			else:
				self._stack[-1].text = data

	
	def get_element_tree(self):
		return self._root


	etree = property(get_element_tree)




tlds = [
	'abogado',
	'ac',
	'academy',
	'accountants',
	'active',
	'actor',
	'ad',
	'adult',
	'ae',
	'aero',
	'af',
	'ag',
	'agency',
	'ai',
	'airforce',
	'al',
	'allfinanz',
	'alsace',
	'am',
	'amsterdam',
	'an',
	'android',
	'ao',
	'apartments',
	'aq',
	'aquarelle',
	'ar',
	'archi',
	'army',
	'arpa',
	'as',
	'asia',
	'associates',
	'at',
	'attorney',
	'au',
	'auction',
	'audio',
	'autos',
	'aw',
	'ax',
	'axa',
	'az',
	'ba',
	'band',
	'bank',
	'bar',
	'barclaycard',
	'barclays',
	'bargains',
	'bayern',
	'bb',
	'bd',
	'be',
	'beer',
	'berlin',
	'best',
	'bf',
	'bg',
	'bh',
	'bi',
	'bid',
	'bike',
	'bingo',
	'bio',
	'biz',
	'bj',
	'black',
	'blackfriday',
	'bloomberg',
	'blue',
	'bm',
	'bmw',
	'bn',
	'bnpparibas',
	'bo',
	'boo',
	'boutique',
	'br',
	'brussels',
	'bs',
	'bt',
	'budapest',
	'build',
	'builders',
	'business',
	'buzz',
	'bv',
	'bw',
	'by',
	'bz',
	'bzh',
	'ca',
	'cab',
	'cal',
	'camera',
	'camp',
	'cancerresearch',
	'canon',
	'capetown',
	'capital',
	'caravan',
	'cards',
	'care',
	'career',
	'careers',
	'cartier',
	'casa',
	'cash',
	'cat',
	'catering',
	'cc',
	'cd',
	'center',
	'ceo',
	'cern',
	'cf',
	'cg',
	'ch',
	'channel',
	'chat',
	'cheap',
	'christmas',
	'chrome',
	'church',
	'ci',
	'citic',
	'city',
	'ck',
	'cl',
	'claims',
	'cleaning',
	'click',
	'clinic',
	'clothing',
	'club',
	'cm',
	'cn',
	'co',
	'coach',
	'codes',
	'coffee',
	'college',
	'cologne',
	'com',
	'community',
	'company',
	'computer',
	'condos',
	'construction',
	'consulting',
	'contractors',
	'cooking',
	'cool',
	'coop',
	'country',
	'cr',
	'credit',
	'creditcard',
	'cricket',
	'crs',
	'cruises',
	'cu',
	'cuisinella',
	'cv',
	'cw',
	'cx',
	'cy',
	'cymru',
	'cz',
	'dabur',
	'dad',
	'dance',
	'dating',
	'day',
	'dclk',
	'de',
	'deals',
	'degree',
	'delivery',
	'democrat',
	'dental',
	'dentist',
	'desi',
	'design',
	'dev',
	'diamonds',
	'diet',
	'digital',
	'direct',
	'directory',
	'discount',
	'dj',
	'dk',
	'dm',
	'dnp',
	'do',
	'docs',
	'domains',
	'doosan',
	'durban',
	'dvag',
	'dz',
	'eat',
	'ec',
	'edu',
	'education',
	'ee',
	'eg',
	'email',
	'emerck',
	'energy',
	'engineer',
	'engineering',
	'enterprises',
	'equipment',
	'er',
	'es',
	'esq',
	'estate',
	'et',
	'eu',
	'eurovision',
	'eus',
	'events',
	'everbank',
	'exchange',
	'expert',
	'exposed',
	'fail',
	'farm',
	'fashion',
	'feedback',
	'fi',
	'finance',
	'financial',
	'firmdale',
	'fish',
	'fishing',
	'fit',
	'fitness',
	'fj',
	'fk',
	'flights',
	'florist',
	'flowers',
	'flsmidth',
	'fly',
	'fm',
	'fo',
	'foo',
	'forsale',
	'foundation',
	'fr',
	'frl',
	'frogans',
	'fund',
	'furniture',
	'futbol',
	'ga',
	'gal',
	'gallery',
	'garden',
	'gb',
	'gbiz',
	'gd',
	'ge',
	'gent',
	'gf',
	'gg',
	'ggee',
	'gh',
	'gi',
	'gift',
	'gifts',
	'gives',
	'gl',
	'glass',
	'gle',
	'global',
	'globo',
	'gm',
	'gmail',
	'gmo',
	'gmx',
	'gn',
	'goog',
	'google',
	'gop',
	'gov',
	'gp',
	'gq',
	'gr',
	'graphics',
	'gratis',
	'green',
	'gripe',
	'gs',
	'gt',
	'gu',
	'guide',
	'guitars',
	'guru',
	'gw',
	'gy',
	'hamburg',
	'hangout',
	'haus',
	'healthcare',
	'help',
	'here',
	'hermes',
	'hiphop',
	'hiv',
	'hk',
	'hm',
	'hn',
	'holdings',
	'holiday',
	'homes',
	'horse',
	'host',
	'hosting',
	'house',
	'how',
	'hr',
	'ht',
	'hu',
	'ibm',
	'id',
	'ie',
	'ifm',
	'il',
	'im',
	'immo',
	'immobilien',
	'in',
	'industries',
	'info',
	'ing',
	'ink',
	'institute',
	'insure',
	'int',
	'international',
	'investments',
	'io',
	'iq',
	'ir',
	'irish',
	'is',
	'it',
	'iwc',
	'jcb',
	'je',
	'jetzt',
	'jm',
	'jo',
	'jobs',
	'joburg',
	'jp',
	'juegos',
	'kaufen',
	'kddi',
	'ke',
	'kg',
	'kh',
	'ki',
	'kim',
	'kitchen',
	'kiwi',
	'km',
	'kn',
	'koeln',
	'kp',
	'kr',
	'krd',
	'kred',
	'kw',
	'ky',
	'kyoto',
	'kz',
	'la',
	'lacaixa',
	'land',
	'lat',
	'latrobe',
	'lawyer',
	'lb',
	'lc',
	'lds',
	'lease',
	'legal',
	'lgbt',
	'li',
	'lidl',
	'life',
	'lighting',
	'limited',
	'limo',
	'link',
	'lk',
	'loans',
	'london',
	'lotte',
	'lotto',
	'lr',
	'ls',
	'lt',
	'ltda',
	'lu',
	'luxe',
	'luxury',
	'lv',
	'ly',
	'ma',
	'madrid',
	'maison',
	'management',
	'mango',
	'market',
	'marketing',
	'marriott',
	'mc',
	'md',
	'me',
	'media',
	'meet',
	'melbourne',
	'meme',
	'memorial',
	'menu',
	'mg',
	'mh',
	'miami',
	'mil',
	'mini',
	'mk',
	'ml',
	'mm',
	'mn',
	'mo',
	'mobi',
	'moda',
	'moe',
	'monash',
	'money',
	'mormon',
	'mortgage',
	'moscow',
	'motorcycles',
	'mov',
	'mp',
	'mq',
	'mr',
	'ms',
	'mt',
	'mu',
	'museum',
	'mv',
	'mw',
	'mx',
	'my',
	'mz',
	'na',
	'nagoya',
	'name',
	'navy',
	'nc',
	'ne',
	'net',
	'network',
	'neustar',
	'new',
	'nexus',
	'nf',
	'ng',
	'ngo',
	'nhk',
	'ni',
	'nico',
	'ninja',
	'nl',
	'no',
	'np',
	'nr',
	'nra',
	'nrw',
	'ntt',
	'nu',
	'nyc',
	'nz',
	'okinawa',
	'om',
	'one',
	'ong',
	'onl',
	'ooo',
	'org',
	'organic',
	'osaka',
	'otsuka',
	'ovh',
	'pa',
	'paris',
	'partners',
	'parts',
	'party',
	'pe',
	'pf',
	'pg',
	'ph',
	'pharmacy',
	'photo',
	'photography',
	'photos',
	'physio',
	'pics',
	'pictures',
	'pink',
	'pizza',
	'pk',
	'pl',
	'place',
	'plumbing',
	'pm',
	'pn',
	'pohl',
	'poker',
	'porn',
	'post',
	'pr',
	'praxi',
	'press',
	'pro',
	'prod',
	'productions',
	'prof',
	'properties',
	'property',
	'ps',
	'pt',
	'pub',
	'pw',
	'py',
	'qa',
	'qpon',
	'quebec',
	're',
	'realtor',
	'recipes',
	'red',
	'rehab',
	'reise',
	'reisen',
	'reit',
	'ren',
	'rentals',
	'repair',
	'report',
	'republican',
	'rest',
	'restaurant',
	'reviews',
	'rich',
	'rio',
	'rip',
	'ro',
	'rocks',
	'rodeo',
	'rs',
	'rsvp',
	'ru',
	'ruhr',
	'rw',
	'ryukyu',
	'sa',
	'saarland',
	'sale',
	'samsung',
	'sarl',
	'saxo',
	'sb',
	'sc',
	'sca',
	'scb',
	'schmidt',
	'schule',
	'schwarz',
	'science',
	'scot',
	'sd',
	'se',
	'services',
	'sew',
	'sexy',
	'sg',
	'sh',
	'shiksha',
	'shoes',
	'shriram',
	'si',
	'singles',
	'sj',
	'sk',
	'sky',
	'sl',
	'sm',
	'sn',
	'so',
	'social',
	'software',
	'sohu',
	'solar',
	'solutions',
	'soy',
	'space',
	'spiegel',
	'sr',
	'st',
	'style',
	'su',
	'supplies',
	'supply',
	'support',
	'surf',
	'surgery',
	'suzuki',
	'sv',
	'sx',
	'sy',
	'sydney',
	'systems',
	'sz',
	'taipei',
	'tatar',
	'tattoo',
	'tax',
	'tc',
	'td',
	'technology',
	'tel',
	'temasek',
	'tennis',
	'tf',
	'tg',
	'th',
	'tienda',
	'tips',
	'tires',
	'tirol',
	'tj',
	'tk',
	'tl',
	'tm',
	'tn',
	'to',
	'today',
	'tokyo',
	'tools',
	'top',
	'toshiba',
	'town',
	'toys',
	'tp',
	'tr',
	'trade',
	'training',
	'travel',
	'trust',
	'tt',
	'tui',
	'tv',
	'tw',
	'tz',
	'ua',
	'ug',
	'uk',
	'university',
	'uno',
	'uol',
	'us',
	'uy',
	'uz',
	'va',
	'vacations',
	'vc',
	've',
	'vegas',
	'ventures',
	'versicherung',
	'vet',
	'vg',
	'vi',
	'viajes',
	'video',
	'villas',
	'vision',
	'vlaanderen',
	'vn',
	'vodka',
	'vote',
	'voting',
	'voto',
	'voyage',
	'vu',
	'wales',
	'wang',
	'watch',
	'webcam',
	'website',
	'wed',
	'wedding',
	'wf',
	'whoswho',
	'wien',
	'wiki',
	'williamhill',
	'wme',
	'work',
	'works',
	'world',
	'ws',
	'wtc',
	'wtf',
	'xn--1qqw23a',
	'xn--3bst00m',
	'xn--3ds443g',
	'xn--3e0b707e',
	'xn--45brj9c',
	'xn--45q11c',
	'xn--4gbrim',
	'xn--55qw42g',
	'xn--55qx5d',
	'xn--6frz82g',
	'xn--6qq986b3xl',
	'xn--80adxhks',
	'xn--80ao21a',
	'xn--80asehdb',
	'xn--80aswg',
	'xn--90a3ac',
	'xn--b4w605ferd',
	'xn--c1avg',
	'xn--cg4bki',
	'xn--clchc0ea0b2g2a9gcd',
	'xn--czr694b',
	'xn--czrs0t',
	'xn--czru2d',
	'xn--d1acj3b',
	'xn--d1alf',
	'xn--fiq228c5hs',
	'xn--fiq64b',
	'xn--fiqs8s',
	'xn--fiqz9s',
	'xn--flw351e',
	'xn--fpcrj9c3d',
	'xn--fzc2c9e2c',
	'xn--gecrj9c',
	'xn--h2brj9c',
	'xn--hxt814e',
	'xn--i1b6b1a6a2e',
	'xn--io0a7i',
	'xn--j1amh',
	'xn--j6w193g',
	'xn--kprw13d',
	'xn--kpry57d',
	'xn--kput3i',
	'xn--l1acc',
	'xn--lgbbat1ad8j',
	'xn--mgb9awbf',
	'xn--mgba3a4f16a',
	'xn--mgbaam7a8h',
	'xn--mgbab2bd',
	'xn--mgbayh7gpa',
	'xn--mgbbh1a71e',
	'xn--mgbc0a9azcg',
	'xn--mgberp4a5d4ar',
	'xn--mgbx4cd0ab',
	'xn--ngbc5azd',
	'xn--node',
	'xn--nqv7f',
	'xn--nqv7fs00ema',
	'xn--o3cw4h',
	'xn--ogbpf8fl',
	'xn--p1acf',
	'xn--p1ai',
	'xn--pgbs0dh',
	'xn--q9jyb4c',
	'xn--qcka1pmc',
	'xn--rhqv96g',
	'xn--s9brj9c',
	'xn--ses554g',
	'xn--unup4y',
	'xn--vermgensberater-ctb',
	'xn--vermgensberatung-pwb',
	'xn--vhquv',
	'xn--wgbh1c',
	'xn--wgbl6a',
	'xn--xhq521b',
	'xn--xkc2al3hye2a',
	'xn--xkc2dl3a5ee0h',
	'xn--yfro4i67o',
	'xn--ygbi2ammx',
	'xn--zfr164b',
	'xxx',
	'xyz',
	'yachts',
	'yandex',
	'ye',
	'yoga',
	'yokohama',
	'youtube',
	'yt',
	'za',
	'zip',
	'zm',
	'zone',
	'zuerich',
	'zw'
]



import platform
from os.path import expanduser, join as joinpath, exists
import sys


def is_linux():
	return platform.system() == 'Linux'


def is_windows():
	return platform.system() == 'Windows'


def is_py3():
	version = platform.python_version()
	return version[0] == '3'


def get_pictures_dir():
	path = joinpath(expanduser('~'), 'Pictures')
	if not exists(path):
		mkdir(path)
	return path


def prints(msg):
	if is_py3():
		if sys.stdout is not None:
			sys.stdout.write(msg + ' ')
			sys.stdout.flush()
	else:
		if sys.stdout is not None:
			print(msg),
			sys.stdout.flush()
	



import ez_setup
ez_setup.use_setuptools()

from setuptools import setup, find_packages
import platform
import imp
from mangoutils.version import __version__


setup(	name='mangoutils',
	description='A collection of commonly useful utilities.',
	version=__version__,
	author='Amol Umrale',
	author_email='babaiscool@gmail.com',
	url='http://pypi.python.org/pypi/mangoutils/',
	packages=['mangoutils', 'mangoutils.web', 'mangoutils.html', 'mangoutils.system'],
	scripts=['ez_setup.py'],
	classifiers=[
		'Development Status :: 4 - Beta',
		'License :: OSI Approved :: MIT License',
		'Natural Language :: English',
		'Operating System :: POSIX :: Linux',
		'Operating System :: Microsoft :: Windows'
	]		
)

